@@ -101,12 +101,12 @@ function(y,data,snpsubset,idsubset,times=1,quiet=FALSE,bcast=10,clambda=TRUE,pro
 	#out
 	if (is.null(Pc1df)) {
 		results <- data.frame(N=N,
-				effB = effB, se_effB = effB/sqrt(chi2.1df), chi2.1df = chi2.1df, P1df = P1df, 
+				effB = effB, se_effB = abs(effB)/sqrt(chi2.1df), chi2.1df = chi2.1df, P1df = P1df, 
 				effAB=effAB, effBB=effBB, chi2.2df = chi2.2df, P2df = P2df,
 				stringsAsFactors = FALSE)
 	} else {
 		results <- data.frame(N=N,
-				effB = effB, se_effB = effB/sqrt(chi2.1df), chi2.1df = chi2.1df, P1df = P1df, 
+				effB = effB, se_effB = abs(effB)/sqrt(chi2.1df), chi2.1df = chi2.1df, P1df = P1df, 
 				Pc1df = Pc1df, 
 				effAB=effAB, effBB=effBB, chi2.2df = chi2.2df, P2df = P2df,
 				stringsAsFactors = FALSE)
