@@ -1,8 +1,18 @@
 "export.merlin" <- 
-function(data,pedfile="merlin.ped",datafile="merlin.dat",
-		mapfile="merlin.map",format="merlin",fixstrand="no",
-		extendedmap=TRUE,traits=1, order = TRUE, stepids = 100) {
+		function(data,pedfile="merlin.ped",datafile="merlin.dat",
+				mapfile="merlin.map",format="merlin",fixstrand="no",
+				extendedmap=TRUE,traits=1, order = TRUE, stepids = 100, dpieceFun="new") {
 	if (!is(data,"gwaa.data")) stop("Data argument should be of gwaa.data-class")
+	dpieceFunOptions <- c("old","new")
+	dpieceFunInt <- match(dpieceFun,dpieceFunOptions,nomatch=0)
+	if (dpieceFunInt<=0) {
+		out <- paste("dpieceFun argument should be one of",dpieceFunOptions,"\n")
+		stop(out)
+	} else {
+		if (dpieceFunInt==1) dump.piece=dump.piece
+		else if (dpieceFunInt==2) dump.piece=dump.piece.New
+		else stop("weird staff!")
+	}
 	formats <- c("merlin","plink")
 	if (!(match(format,formats,nomatch=0)>0)) {
 		out <- paste("format argument should be one of",formats,"\n")
@@ -15,27 +25,27 @@ function(data,pedfile="merlin.ped",datafile="merlin.dat",
 	}
 	if (order) {
 		ord <- sortmap.internal(chromosome(data),map(data))
-		data <- data[,ord$ix]
+		if (any(ord$ix != c(1:length(ord$ix)))) {data <- data[,ord$ix]; gc()}
 	}
 	if (fixstrand != "no") {
-###### as.raw(1) == "+"
-###### as.raw(2) == "-"
+		###### as.raw(1) == "+"
+		###### as.raw(2) == "-"
 		if (fixstrand == "-") {tos <- as.raw(1);fos<-as.raw(2);} 
-			else if (fixstrand == "+") {tos <- as.raw(2);fos <- as.raw(1)}
-			else {stop("strange strand...")}
+		else if (fixstrand == "+") {tos <- as.raw(2);fos <- as.raw(1)}
+		else {stop("strange strand...")}
 		stf <- which(as.raw(data@gtdata@strand) == tos) 
 		if (length(stf)>0) {
-		  revs <- alleleID.revstrand()
-  		  savnam <- names(data@gtdata@strand)
+			revs <- alleleID.revstrand()
+			savnam <- names(data@gtdata@strand)
 #
 #		data@gtdata@coding[stf] <- new("snp.coding",as.raw(revs[as.character(data@gtdata@coding[stf])]))
 #
 #		ugly fix -- 
 #
-		  data@gtdata@coding[stf] <- new("snp.coding",as.raw(revs[as.character(as.raw(data@gtdata@coding[stf]))]))
-		  names(data@gtdata@coding) <- savnam
-		  data@gtdata@strand[stf] <- new("snp.strand",rep(fos,length(stf)))
-		  names(data@gtdata@strand) <- savnam
+			data@gtdata@coding[stf] <- new("snp.coding",as.raw(revs[as.character(as.raw(data@gtdata@coding[stf]))]))
+			names(data@gtdata@coding) <- savnam
+			data@gtdata@strand[stf] <- new("snp.strand",rep(fos,length(stf)))
+			names(data@gtdata@strand) <- savnam
 		}
 	}
 	bstp <- stepids #100
@@ -43,10 +53,12 @@ function(data,pedfile="merlin.ped",datafile="merlin.dat",
 		steps <- seq(from=0,to=data@gtdata@nids,by=bstp)
 		if (data@gtdata@nids != steps[length(steps)]) steps[length(steps)+1] <- data@gtdata@nids
 		dump.piece(data=data,from=1,to=steps[2],traits=traits,
-				pedfile=pedfile,append=F,format=format)
+				pedfile=pedfile,append=FALSE,format=format)
+		cat("dumped ids",1,"to",steps[2],"\n")
 		for (jjj in c(2:(length(steps)-1))) {
 			dump.piece(data=data,from=(steps[jjj]+1),to=(steps[jjj+1]),traits=traits,
-					pedfile=pedfile,append=T,format=format)
+					pedfile=pedfile,append=TRUE,format=format)
+			cat("dumped ids",steps[jjj]+1,"to",steps[jjj+1],"\n")
 		}
 	} else {
 		dump.piece(data=data,from=1,to=data@gtdata@nids,traits=traits,
@@ -98,3 +110,18 @@ dump.piece <- function(data,fromid,toid,traits,pedfile,append,format="merlin") {
 	}
 	write.table(x,file=pedfile,col.n=FALSE,row.n=FALSE,quote=FALSE,append=append,sep=" ")
 }
+
+dump.piece.New <- function(data,fromid,toid,traits,pedfile,append,format="merlin") {
+	if (toid < fromid) stop("toid<fromid")
+	# ugly line -- should be in the C++ code
+	if (!append) unlink(pedfile);
+	if (format=="plink") {plink <- TRUE;} else {plink <- FALSE;}
+	#data <- data[c(fromid:toid),]
+	result <- .Call("export_plink",as.character(idnames(data)[c(fromid:toid)]),
+			as.raw(gtdata(data)@gtps), as.integer(nsnps(data)), as.integer(nids(data)),
+			as.character(coding(data)), as.integer(fromid), as.integer(toid),
+			as.integer(male(data)), as.integer(traits), as.character(pedfile), 
+			as.logical(plink), as.logical(append))
+	#
+	return(1)
+}
